@@ -5,7 +5,7 @@ function(Product)
 
   getbands.xml <- paste('
     <soapenv:Envelope xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema"
-             xmlns:soapenv="http://schemas.xmlsoap.org/soap/envelope/" xmlns:mod="http://daacmodis.ornl.gov/MODIS_webservice">
+             xmlns:soapenv="http://schemas.xmlsoap.org/soap/envelope/" xmlns:mod="', daacmodis, '/MODIS_webservice">
                          <soapenv:Header/>
                          <soapenv:Body>
                          <mod:getbands soapenv:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
@@ -23,7 +23,7 @@ function(Product)
   reader <- basicTextGatherer()
   header <- basicTextGatherer()
 
-  curlPerform(url = "http://daacmodis.ornl.gov/cgi-bin/MODIS/GLBVIZ_1_Glb_subset/MODIS_webservice.pl",
+  curlPerform(url = paste0(daacmodis, wsdl_loc),
               httpheader = header.fields,
               postfields = getbands.xml,
               writefunction = reader$update,
@@ -32,8 +32,7 @@ function(Product)
   # Check the server is not down by insepcting the XML response for internal server error message.
   if(grepl("Internal Server Error", reader$value())){
     stop("Web service failure: the ORNL DAAC server seems to be down, please try again later.
-         The online subsetting tool (http://daac.ornl.gov/cgi-bin/MODIS/GLBVIZ_1_Glb/modis_subset_order_global_col5.pl)
-         will indicate when the server is up and running again.")
+         The online subsetting tool may indicate when the server is up and running again.")
   }
 
   xmlres <- xmlRoot(xmlTreeParse(reader$value()))
@@ -49,4 +48,4 @@ function(Product)
   } else{
     return(as.vector(bandsres))
   }
-}
\ No newline at end of file
+}
