@@ -13,7 +13,7 @@ function(Lat, Long, Product, Band, StartDate, EndDate, KmAboveBelow, KmLeftRight
 
   getsubset.xml <- paste('
     <soapenv:Envelope xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema"
-             xmlns:soapenv="http://schemas.xmlsoap.org/soap/envelope/" xmlns:mod="http://daacmodis.ornl.gov/MODIS_webservice">
+             xmlns:soapenv="http://schemas.xmlsoap.org/soap/envelope/" xmlns:mod="', daacmodis, '/MODIS_webservice">
                          <soapenv:Header/>
                          <soapenv:Body>
                          <mod:getsubset soapenv:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
@@ -38,7 +38,7 @@ function(Lat, Long, Product, Band, StartDate, EndDate, KmAboveBelow, KmLeftRight
   reader <- basicTextGatherer()
   header <- basicTextGatherer()
 
-  curlPerform(url = "http://daacmodis.ornl.gov/cgi-bin/MODIS/GLBVIZ_1_Glb_subset/MODIS_webservice.pl",
+  curlPerform(url = paste0(daacmodis, wsdl_loc),
               httpheader = header.fields,
               postfields = getsubset.xml,
               writefunction = reader$update,
@@ -47,7 +47,7 @@ function(Lat, Long, Product, Band, StartDate, EndDate, KmAboveBelow, KmLeftRight
   # Check the server is not down by insepcting the XML response for internal server error message.
   if(grepl("Internal Server Error", reader$value())){
     stop("Web service failure: the ORNL DAAC server seems to be down, please try again later.
-         The online subsetting tool (http://daac.ornl.gov/cgi-bin/MODIS/GLBVIZ_1_Glb/modis_subset_order_global_col5.pl)
+         The online subsetting tool (https://daac.ornl.gov/cgi-bin/MODIS/GLBVIZ_1_Glb/modis_subset_order_global_col5.pl)
          will indicate when the server is up and running again.")
   }
 
@@ -67,4 +67,4 @@ function(Lat, Long, Product, Band, StartDate, EndDate, KmAboveBelow, KmLeftRight
     names(modisres) <- c("xll", "yll", "pixelsize", "nrow", "ncol", "band", "scale", "lat", "long", "subset")
     return(modisres)
   }
-}
\ No newline at end of file
+}
